@@ -13,8 +13,8 @@ logger = get_default_logger()
 
 def pynonymize(
         input_path=None, strategyfile_path=None, output_path=None, db_user=None, db_password=None, db_type=None,
-        db_host=None, db_name=None, fake_locale=None, start_at_step=None, stop_at_step=None, skip_steps=None,
-        seed_rows=None,
+        db_host=None, db_name=None, db_port=None, fake_locale=None, start_at_step=None, stop_at_step=None, skip_steps=None,
+        seed_rows=None, dry_run=False, verbose=False,
 
         **kwargs
     ):
@@ -42,7 +42,7 @@ def pynonymize(
     if seed_rows is None:
         seed_rows = 150
 
-    actions = StepActionMap(start_at_step, stop_at_step, skip_steps)
+    actions = StepActionMap(start_at_step, stop_at_step, skip_steps, dry_run=dry_run)
 
     # Validate mandatory args (depends on step actions)
     validations = []
@@ -91,13 +91,14 @@ def pynonymize(
         if k.startswith(db_arg_prefix):
             db_kwargs[ k[len(db_arg_prefix):] ] = v
 
-    logger.debug("Database: (%s)%s@%s db_name: %s", db_host, db_type, db_user, db_name)
+    logger.debug("Database: (%s:%s)%s@%s name: %s", db_host, db_port, db_type, db_user, db_name)
     db_provider = get_provider(
         type=db_type,
         db_host=db_host,
         db_user=db_user,
         db_pass=db_password,
         db_name=db_name,
+        db_port=db_port,
         seed_rows=seed_rows,
         **db_kwargs
     )
@@ -105,7 +106,7 @@ def pynonymize(
     if not db_provider.test_connection():
         raise DatabaseConnectionError()
 
-    # main process
+    # main process - no destructive/non-retryable actions should happen before this line ---
     logger.info(actions.summary(ProcessSteps.CREATE_DB))
     if not actions.skipped(ProcessSteps.CREATE_DB):
         db_provider.create_database()
@@ -126,4 +127,4 @@ def pynonymize(
     if not actions.skipped(ProcessSteps.DROP_DB):
         db_provider.drop_database()
 
-    logger.info("Process complete!")
\ No newline at end of file
+    logger.info("Process complete!")
