@@ -30,6 +30,7 @@ class MainArgTests(unittest.TestCase):
             output="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -38,7 +39,9 @@ class MainArgTests(unittest.TestCase):
             skip_steps=["TEST_SKIP_1", "TEST_SKIP_2"],
             stop_at_step="TEST_STOP_AT_STEP",
             seed_rows=None,
-            mssql_backup_compression=False
+            mssql_backup_compression=False,
+            dry_run=True,
+            verbose=True
         )
     def test_dotenv_called(self, pynonymize, create_parser, load_dotenv, find_dotenv):
         """
@@ -73,6 +76,7 @@ class MainArgTests(unittest.TestCase):
             output_path="LEGACY_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -81,7 +85,9 @@ class MainArgTests(unittest.TestCase):
             skip_steps=["TEST_SKIP_1", "TEST_SKIP_2"],
             stop_at_step="TEST_STOP_AT_STEP",
             seed_rows=None,
-            mssql_backup_compression=False
+            mssql_backup_compression=False,
+            dry_run=True,
+            verbose=True
         )
 
     def test_arg_pass_normal(self, pynonymize, create_parser, load_dotenv, find_dotenv):
@@ -101,6 +107,7 @@ class MainArgTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -109,7 +116,9 @@ class MainArgTests(unittest.TestCase):
             skip_steps=["TEST_SKIP_1", "TEST_SKIP_2"],
             stop_at_step="TEST_STOP_AT_STEP",
             seed_rows=None,
-            mssql_backup_compression=False
+            mssql_backup_compression=False,
+            dry_run=True,
+            verbose=True
         )
 
 
@@ -158,6 +167,7 @@ class MainProcessTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="mssql",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -166,7 +176,7 @@ class MainProcessTests(unittest.TestCase):
             mssql_special_provider_var="TEST_DYNAMIC_VAR2"
         )
         StrategyParser.return_value.parse_config.assert_called()
-        get_provider.assert_called_with(type="mssql", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150, special_provider_var="TEST_DYNAMIC_VAR2")
+        get_provider.assert_called_with(type="mssql", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150, special_provider_var="TEST_DYNAMIC_VAR2")
 
     def test_pynonymize_main_process(self, StrategyParser, FakeColumnSet, get_provider, read_config):
         """
@@ -178,6 +188,7 @@ class MainProcessTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -185,7 +196,7 @@ class MainProcessTests(unittest.TestCase):
             seed_rows=999
         )
         StrategyParser.return_value.parse_config.assert_called()
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=999)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT",  db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=999)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -202,6 +213,7 @@ class MainProcessTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -209,7 +221,7 @@ class MainProcessTests(unittest.TestCase):
             stop_at_step="ANONYMIZE_DB"
         )
         StrategyParser.return_value.parse_config.assert_called()
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -227,13 +239,14 @@ class MainProcessTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
             fake_locale="TEST_LOCALE",
             skip_steps=["ANONYMIZE_DB", "CREATE_DB", "DUMP_DB"]
         )
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -251,6 +264,7 @@ class MainProcessTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -258,7 +272,7 @@ class MainProcessTests(unittest.TestCase):
             start_at_step="ANONYMIZE_DB"
         )
         StrategyParser.return_value.parse_config.assert_called()
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -299,6 +313,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -309,7 +324,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
         )
 
         StrategyParser.return_value.parse_config.assert_called()
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -327,6 +342,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -337,7 +353,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
         )
 
         StrategyParser.return_value.parse_config.assert_called()
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -355,6 +371,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -364,7 +381,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             skip_steps=None
         )
 
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -382,6 +399,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -390,7 +408,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             stop_at_step=None,
             skip_steps=["ANONYMIZE_DB"]
         )
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -408,6 +426,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -416,7 +435,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             stop_at_step=None,
             skip_steps=None
         )
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -434,6 +453,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             output_path="TEST_OUTPUT",
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -442,7 +462,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             stop_at_step="RESTORE_DB",
             skip_steps=None
         )
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -460,6 +480,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             output_path=None,
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -470,7 +491,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
         )
 
         StrategyParser.return_value.parse_config.assert_called()
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -488,6 +509,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             output_path=None,
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -496,7 +518,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             stop_at_step=None,
             skip_steps=None
         )
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
@@ -514,6 +536,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
             output_path=None,
             db_type="TEST_TYPE",
             db_host="TEST_HOST",
+            db_port="TEST_PORT",
             db_name="TEST_NAME",
             db_user="TEST_USER",
             db_password="TEST_PASSWORD",
@@ -524,7 +547,7 @@ class OptionalArgumentsSkippedTests(unittest.TestCase):
         )
 
         StrategyParser.return_value.parse_config.assert_called()
-        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
+        get_provider.assert_called_with(type="TEST_TYPE", db_host="TEST_HOST", db_port="TEST_PORT", db_user="TEST_USER", db_pass="TEST_PASSWORD", db_name="TEST_NAME", seed_rows=150)
 
         provider = get_provider.return_value
         provider.test_connection.assert_called()
